@@ -123,7 +123,7 @@ public:
 
     void setRules(const QVector<Rule*> &newrules);
     void setArgs(const QVariantMap &args);
-    void setEnabled(const bool &value);
+    void setEnabled(bool value);
     void setDefaultIncomingPolicy(const QString &policy);
     void setDefaultOutgoingPolicy(const QString &policy);
 
